# Magandi - Python Package

Welcome to the Magandi python package repository! 🐍

## Overview
Magandi is a super cool python package that allows you to easily work with videos and images. It provides powerful tools for image and video manipulation in Python.

## Installation
You can install Magandi via PyPI. Simply run:

```pip install Mangandi```

## Support
Join our Telegram support group [Support](https://t.me/XBOTSUPPORTS) for any help or queries related to Magandi.
